# $Id$

=head1 NAME

WWW::Shorten::Metamark - Perl interface to metamark.net

=head1 SYNOPSIS

    # No appropriate synopsis

=head1 DESCRIPTION

A Perl interface to the web site metamark.net.

From September 2014, Metamark is no longer accepting new URLs.

=cut

package WWW::Shorten::Metamark;

use 5.006;
use strict;
use warnings;

our $VERSION = '1.91';

require WWW::Shorten::_dead;

0;
